==> org.eclipse.net4j.source_3.0.1.v20110120-1046.jar: org/eclipse/net4j/signal/ISignalProtocol.java <==
/**
 * Copyright (c) 2004 - 2010 Eike Stepper (Berlin, Germany) and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Eike Stepper - initial API and implementation
 */
package org.eclipse.net4j.signal;

import org.eclipse.net4j.buffer.BufferInputStream;
import org.eclipse.net4j.channel.IChannel;
import org.eclipse.net4j.connector.IConnector;
import org.eclipse.net4j.protocol.IProtocol;
import org.eclipse.net4j.signal.failover.IFailOverStrategy;
import org.eclipse.net4j.util.event.INotifier;
import org.eclipse.net4j.util.io.IStreamWrapper;

/**
 * @author Eike Stepper
 * @since 2.0
 */
public interface ISignalProtocol<INFRA_STRUCTURE> extends IProtocol<INFRA_STRUCTURE>, INotifier
{
  public static final long NO_TIMEOUT = BufferInputStream.NO_TIMEOUT;

  public static final long DEFAULT_TIMEOUT = 10 * 1000L;

  public long getTimeout();

  public void setTimeout(long timeout);

  public IStreamWrapper getStreamWrapper();

  public void setStreamWrapper(IStreamWrapper streamWrapper);

  public void addStreamWrapper(IStreamWrapper streamWrapper);

  public IFailOverStrategy getFailOverStrategy();

  public void setFailOverStrategy(IFailOverStrategy failOverStrategy);

  public IChannel open(IFailOverStrategy failOverStrategy);

  public IChannel open(IConnector connector);

  public IChannel open();

  public void close();
}

==> org.eclipse.net4j.source_4.21.1.v20251224-1240.jar: org/eclipse/net4j/signal/ISignalProtocol.java <==
/*
 * Copyright (c) 2008-2012, 2021 Eike Stepper (Loehne, Germany) and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *    Eike Stepper - initial API and implementation
 */
package org.eclipse.net4j.signal;

import org.eclipse.net4j.buffer.BufferInputStream;
import org.eclipse.net4j.channel.IChannel;
import org.eclipse.net4j.connector.IConnector;
import org.eclipse.net4j.protocol.IProtocol;
import org.eclipse.net4j.util.event.INotifier;
import org.eclipse.net4j.util.io.IStreamWrapper;

/**
 * A {@link IProtocol protocol} that consists of a number of stream-based {@link Signal signals}.
 *
 * @author Eike Stepper
 * @since 2.0
 */
public interface ISignalProtocol<INFRA_STRUCTURE> extends IProtocol<INFRA_STRUCTURE>, INotifier
{
  public static final long NO_TIMEOUT = BufferInputStream.NO_TIMEOUT;

  public static final long DEFAULT_TIMEOUT = 10 * 1000L;

  public long getTimeout();

  public void setTimeout(long timeout);

  public IStreamWrapper getStreamWrapper();

  public void setStreamWrapper(IStreamWrapper streamWrapper);

  public void addStreamWrapper(IStreamWrapper streamWrapper);

  public IChannel open(IConnector connector);

  public void close();

  /**
   * @author Eike Stepper
   * @since 4.13
   */
  public interface WithSignalCounters<INFRA_STRUCTURE> extends ISignalProtocol<INFRA_STRUCTURE>
  {
    public long getSentSignals();

    public long getReceivedSignals();
  }
}
